******************************************************************************************
******************************************************************************************
**** Code files for "How Elastic Are Preferences for Redistribution:                 *****
**** Evidence from Randomized Survey Experiments."                                   *****                  
******************************************************************************************
*** Authors: Ilyana Kuziemko, Michael Norton, Emmanuel Saez and Stefanie Stantcheva  *****
*** Date: November 2014                                                              *****
*** For questions and comments please contact Stefanie Stantcheva                    *****
*** sstantcheva@fas.harvard.edu                                                      *****
******************************************************************************************
******************************************************************************************

******************************************************************************************
******* Emotional Poverty, Policy and Inequality only Treatment                             
******************************************************************************************
******* input: Inequality_AER_IneqPovPol.dta, data from the supplementary ``emotional 
******* poverty'', ``policy'' and ``pure inequality'' experiments
******* output: main paper and appendix tables for all poverty and policy results
******************************************************************************************


* Modify the path here to the folder where you placed the datasets

* Please check the variable labels and value labels, which show the survey question asked
* and the answer choices given to respondents.

cd "/Users/stefaniestantcheva/Dropbox/inequality/AER_revision2/data/"

clear
set mem 500m
set more off

cap log close
log using ineq_IneqPovPol.log, replace

* wave variable refers to different waves of collection of the data. Here is a list of the "waves" in this data: 
* wave == 1: 1st Inequality pilot, sample size 200
* wave == 2: 2nd Inequality pilot, sample size 200
* wave == 3: 1st Poverty pilot, sample size 200
* wave == 4: 1st Policy pilot, sample size 300
* wave == 6: 3rd (and large) Inequality pilot, 1000
* wave == 5: Large sample with Inequality, Poverty and policy treatments, each of size 500, against a control group of 500 as well. 

* Note that in the regressions, we condition on wave so that we only use the groups that were subject to each respective treatment. 

use Inequality_AER_IneqPovPol.dta, replace

******************************************************************************************
********* Definition of background variables 
******************************************************************************************

gen obama12 = . 
gen temp=party2012==1 if party2012~=.
replace obama12=temp if obama12==.

gen male=gender==1 if gender~=.
gen native=usborn==1 if usborn~=.
gen married=marital==2 if marital~=.
gen white=ethnic==1 if ethnic~=.
gen black=ethnic==2 if ethnic~=.
gen hisp=ethnic==3 if ethnic~=.
gen asian=ethnic==4 if ethnic~=.
gen college=educ>5 if educ~=.
gen fulltime=employ==1 if employ~=.
gen unemp=employ==4 if employ~=.
gen student=employ==5 if employ~=.
gen nilf=employ==6 if employ~=.
qui tab hhincome, missing gen(hhh) 
gen liberal=policyview>3 if policyview~=. 
gen conservative = policyview<=2 if policyview~=. 
tab ethnic, gen(eee)

****Create 3-category policyview to compare with polling data
gen policyview3=1 if policyview<3
replace policyview3=2 if policyview==3
replace policyview3=3 if policyview>3 & policyview~=.

**** Create round fixed effects, 
tab wave, gen(www)

******************************************************************************************
********* Definition of outcome variables 
******************************************************************************************

* Please also check the definition of all outcome variables described in the Appendix.

* Binary variable equal to 1 if respondent says should increase tax on millionaires: 
gen inc_mill_yes=tax_mill==1 if tax_mill~=.
* Binary variable equal to 1 if respondent says should increase estate tax: 
gen inc_estate_yes=estate_tax==3 if estate_tax~=.
* Vote for democrat or republican in 2014
gen democrat14=(party2014==1) if party2014~=.
gen republican14 = (party2014 == 2) if party2014~=.

*** Trust variables: We flip them around but in one wave they were already flipped around, so careful!
replace trust_government=5-trust_government if wave != 6
*Now, 1 = hardly ever trust, 4 = just about always
* Trust the government binary variable
gen trust_gov_yes=trust_government>2 if trust_government~=. 
label var trust_gov_yes "Yes, trust the government"

gen nowaste = waste_government 

* nofraud: increasing means, there is no fraud.
gen nofraud = 5-t_fraud
* nolobby: increasing means, little lobbying.
gen nolobby = t_lobby

replace deserving=4-deserving if wave != 6

* Binary outcome "Inequality has increased"
gen ineq_inc_yes=inequality_increase==3 if inequality_increase~=.

* Binary outcome 'Inequality is very serious"
gen ineq_vs=inequality_problem==5 if inequality_problem~=. 

* Binary outcome "Poverty is very serious"
gen pov_vs=poverty_problem==5 if poverty_problem~=. 

* The high income people are deserving of their income
gen deserving_yes=deserving==3 if deserving~=. 
label var deserving "High income people are deserving of their income"

** Binary variables for correct answers given to test of understanding questions: 
gen poverty_correct = (poverty_rate == 3) if poverty_rate != . 
gen childpoverty_correct = (childpoverty_rate == 2) if childpoverty_rate != . 
gen minwage_correct = (earnminwage == 2) if earnminwage != . 

* Housing and aid to poor only appeared in later waves, always with 5 options:
gen inc_housing = 5-housing if housing !=. 
gen inc_aid=5-aidpoor if aidpoor~=. 
gen inc_mw  = 5-minwage if minwage != . 
gen inc_food = 5-foodstamps if foodstamps != . 

gen petition_high_estate=petition==1 if petition!=.
label var petition_high_estate "Said would petition for higher estate taxes"

* Variables that rank the various tools to address inequality
replace tools_inequality_1 = 6-tools_inequality_1
replace tools_inequality_2 = 6-tools_inequality_2
replace tools_inequality_3 = 6-tools_inequality_3
replace tools_inequality_4 = 6-tools_inequality_4
replace tools_inequality_5 = 6-tools_inequality_5

** Generate variables that show whether people underestimate the budget of poor households in the policy treatment
* totalsum is 1100, totalsum2 is 1100, totalsum3 is 1100, totalsum4 is 1100
gen underestimate_pol = 0 if totalsum != . | totalsum2 !=. | totalsum3 != . | totalsum4 !=. 
replace underestimate_pol = 1 if (totalsum > 1100 & totalsum != .) | (totalsum2 > 1100 & totalsum2 != .) ///
| (totalsum3 > 1100 & totalsum3 !=.) | (totalsum4 > 1100 & totalsum4 !=.)

gen underestimate_pol2 = 0 if totalsum != . | totalsum2 !=. | totalsum3 != . | totalsum4 !=. 
replace underestimate_pol2 = 1 if (totalsum > 1650 & totalsum != .) | (totalsum2 > 1650 & totalsum2 != .) ///
| (totalsum3 > 1650 & totalsum3 !=.) | (totalsum4 > 1650 & totalsum4 !=.)

** Underestimate the budget? for poverty
* totalsumpov is 1650, totalsumpov2 is 970, totalsumpov3 is 1990, totalsumpov4 is 1300

gen underestimate_pov = 0 if totalsumpov != . | totalsumpov2 !=. | totalsumpov3 != . | totalsumpov4 !=. 
replace underestimate_pov = 1 if (totalsumpov > 1650 & totalsumpov != .) | (totalsumpov2 > 970 & totalsumpov2 != .) ///
| (totalsumpov3 > 1990 & totalsumpov3 !=.) | (totalsumpov4 > 1300 & totalsumpov4 !=.)

gen underestimate_pov2 = 0 if totalsumpov != . | totalsumpov2 !=. | totalsumpov3 != . | totalsumpov4 !=. 
replace underestimate_pov2 = 1 if (totalsumpov > 1650*1.5 & totalsumpov != .) | (totalsumpov2 > 970*1.5 & totalsumpov2 != .) ///
| (totalsumpov3 > 1990*1.5 & totalsumpov3 !=.) | (totalsumpov4 > 1300*1.5 & totalsumpov4 !=.)

gen treat = . 
replace treat = 1 if treat1 == 1
replace treat = 2 if treat2 == 1
replace treat = 3 if treat3 == 1
replace treat = 0 if treat1 == 0 & treat2 == 0 & treat3 == 0

******************************************************************************************
** Do some summary stats for attrition; 
******************************************************************************************

sort treat
egen totaltaken = count(treat), by(treat)
egen totalcompleted = total(finished), by(treat) 
gen fractioncomplete = totalcompleted/totaltaken 

summarize fractioncomplete if treat == 0
summarize fractioncomplete if treat == 1
summarize fractioncomplete if treat == 2
summarize fractioncomplete if treat == 3 

* count finished surveys in the Poverty treatment
count if finished == 1 & (wave == 3 | (wave == 5 & treat1 == 0 & treat2 == 0 ))

* count finished surveys in the Policy treatment
count if finished == 1 & (wave == 4 | (wave == 5 & treat1 == 0 & treat3 == 0))

drop totaltaken totalcompleted fractioncomplete

* control group attrition per relevant control group
count if finished == 1 & (wave == 3  | wave == 5) & treat == 0
count if (wave == 3  | wave == 5) & treat == 0
count if finished == 1 & (wave == 4  | wave == 5) & treat == 0
count if (wave == 4  | wave == 5) & treat == 0

drop treat

local controls "obama12 age policyview hhincome educ male black hisp native unemp nilf student eee* www* married fulltime "  

# delimit; 

* Conditional on finishing the survey
* The endofsurv variables did not exist in all waves; 
drop if (endofsurv=="" & wave !=3 & wave!= 6);

gen missing=0 ;

******************************************************************************************
******* TABLES FOR THE MAIN PAPER ;
******************************************************************************************;

**********************POVERTY TREATMENT;

** For these regressions, we consider only the sample that was in the poverty treatment
** i.e., if wave == 3 | wave == 5

drop if treat1 ==. ;
drop if treat2 == . ;
drop if treat3 ==. ;


label var treat3 "Treated"; 

eststo clear ;
foreach var of varlist ineq_vs ineq_inc pov_vs inc_mw inc_aid inc_food inc_housing trust_gov_yes { ;
eststo: areg `var' treat3 `controls' if missing==0 & treat1 != 1 & treat2 != 1 & (wave == 3 | wave == 5) , abs(state) ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & (wave == 3 | wave == 5) ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & liberal ==  1 & (wave == 3 | wave == 5); 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & conservative ==  1 & (wave == 3 | wave == 5); 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled3 = abs(_b[treat3]/`lib_cons'); 

} ;

esttab using poverty.tex, replace fragment booktabs keep(treat3) label 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled3 N, label("Control mean" "Scaled Poverty Effect" "Obs."))  ;

tab wave if e(sample) == 1;


**********************POLICY TREATMENT;

** For these regressions, we consider only the sample that was in the policy treatment, 
** i.e., if wave == 4 or wave == 5

label var treat2 "Treated"; 

eststo clear ;
foreach var of varlist ineq_vs pov_vs inc_mw inc_aid inc_food inc_housing tools_inequality_2 trust_gov_yes { ;
eststo: areg `var' treat2 `controls' if missing==0 & treat1 != 1 & treat3 != 1 & (wave == 4 | wave == 5), abs(state) ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0  & (wave == 4 | wave == 5);
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & liberal ==  1  & (wave == 4 | wave == 5); 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & conservative ==  1  & (wave == 4 | wave == 5); 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled2 = abs(_b[treat2]/`lib_cons'); 

} ;

esttab using policy.tex, replace fragment booktabs keep(treat2) label 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled2 N, label("Control mean" "Scaled Policy Effect" "Obs."))  ;

******************************************************************************************
******* APPENDIX TABLES WITH COMPLETE SET OF OUTCOMES
******************************************************************************************

****** Poverty 1 *********;

label var treat3 "Treated"; 

eststo clear ;
foreach var of varlist ineq_vs ineq_inc_yes poverty_correct childpoverty_correct minwage_correct pov_vs deserving_yes taxrate1_1 
inc_mill_yes inc_estate_yes 
petition_high_est { ;
eststo: areg `var' treat3 `controls' if missing==0 & treat1 != 1 & treat2 != 1 & (wave == 3 | wave == 5), abs(state) ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & (wave == 3 | wave == 5);
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & liberal ==  1 & (wave == 3 | wave == 5); 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & conservative ==  1 & (wave == 3 | wave == 5); 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled3 = abs(_b[treat3]/`lib_cons'); 

} ;

esttab using poverty1.tex, replace fragment booktabs keep(treat3) label 
mgroups("Ineq. v. ser." "Ineq. inc." "Pov. corr." "Childpov. corr." "Min wage corr." "Pov. vs." "Deserving" "Top tax" "Mill. tax" "Estate" "Petition", pattern(1 1 1 1 1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled3 N, label("Control mean" "Scaled Poverty Effect" "Obs."))  ;


****** Poverty 2 *********;

eststo clear ;
foreach var of varlist inc_mw inc_aid inc_food inc_housing trust_gov_yes purpose_government nowaste democrat14 
tools_inequality_2 tools_inequality_1 { ;
eststo: areg `var' treat3 `controls' if missing==0 & treat1 != 1 & treat2 != 1 & (wave == 3 | wave == 5), abs(state) ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & (wave == 3 | wave == 5);
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & liberal ==  1 & (wave == 3 | wave == 5); 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & conservative ==  1 & (wave == 3 | wave == 5); 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled3 = abs(_b[treat3]/`lib_cons'); 

} ;

esttab using poverty2.tex, replace fragment booktabs keep(treat3) label 
mgroups("Min wage" "Aid" "Food st." "Housing" "Trust" "Scope" "No waste" "Dem. 2014" "Charity" "Educ. pol.", pattern(1 1 1 1 1 1 1 1 1 1 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled3 N, label("Control mean" "Scaled Poverty Effect" "Obs."))  ;


****** Policy 1 *********;

label var treat2 "Treated"; 

eststo clear ;
foreach var of varlist ineq_vs ineq_inc_yes poverty_correct childpoverty_correct minwage_correct pov_vs deserving_yes taxrate1_1 
inc_mill_yes inc_estate_yes 
petition_high_est { ;
eststo: areg `var' treat2 `controls' if missing==0 & treat1 != 1 & treat3 != 1  & (wave == 4 | wave == 5), abs(state) ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0  & (wave == 4 | wave == 5) ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & liberal ==  1  & (wave == 4 | wave == 5); 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & conservative ==  1  & (wave == 4 | wave == 5); 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled2 = abs(_b[treat2]/`lib_cons'); 

} ;

esttab using policy1.tex, replace fragment booktabs keep(treat2) label 
mgroups("Ineq. v. ser." "Ineq. inc." "Pov. corr." "Childpov. corr." "Min wage corr." "Pov. vs." "Deserving" "Top tax" "Mill. tax" "Estate" "Petition", pattern(1 1 1 1 1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled2 N, label("Control mean" "Scaled Policy Effect" "Obs."))  ;


****** Policy 2 *********;

eststo clear ;
foreach var of varlist inc_mw inc_aid inc_food inc_housing trust_gov_yes purpose_government nowaste democrat14 tools_inequality_2 
tools_inequality_1 { ;
eststo: areg `var' treat2 `controls' if missing==0 & treat1 != 1 & treat3 != 1  & (wave == 4 | wave == 5), abs(state) ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0  & (wave == 4 | wave == 5);
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & liberal ==  1  & (wave == 4 | wave == 5); 
local meanlib = `r(mean)'; 
qui sum `var' if treat1==0 & treat2 == 0 & treat3 == 0 & conservative ==  1  & (wave == 4 | wave == 5); 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled2 = abs(_b[treat2]/`lib_cons'); 

} ;

esttab using policy2.tex, replace fragment booktabs keep(treat2) label 
mgroups("Min wage" "Aid" "Food st." "Housing" "Trust" "Scope" "No waste" "Dem. 2014" "Charity" "Educ. pol.", pattern(1 1 1 1 1 1 1 1 1 1 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled2 N, label("Control mean" "Scaled Policy Effect" "Obs."))  ;


cap log close; 
exit ;

